@@ -1,8 +1,9 @@
 from typing import List
 
-from src.models.page_query_model import PageQueryModel
 from fastapi_pagination import Page, Params, paginate
 
+from src.pagination.page_query_model import PageQueryModel
+
 
 def paginate_list(item_list: List[any], page: int, size: int) -> PageQueryModel:
     paginated_result: Page = paginate(
